@@ -45,17 +45,21 @@ public class EventHandlers {
 	}
 
 	public void OnFileSave (object o, EventArgs args) {
-		Base.Ui.Save();
+		//Save the subtitles
+		Boolean saved = Base.Ui.Save();
 
-		if (Base.Document.IsTranslationLoaded && Base.Config.FileTranslationSaveAll) {
+		//Save the translation
+		if (saved && Base.Document.IsTranslationLoaded && Base.Config.FileTranslationSaveAll) {
 			OnFileTranslationSave(o, args);
 		}
 	}
 
 	public void OnFileSaveAs (object o, EventArgs args) {
-		Base.Ui.SaveAs();
+		//Save the subtitles
+		Boolean saved = Base.Ui.SaveAs();
 
-		if (Base.Document.IsTranslationLoaded && Base.Config.FileTranslationSaveAll) {
+		//Save the translation
+		if (saved && Base.Document.IsTranslationLoaded && Base.Config.FileTranslationSaveAll) {
 			OnFileTranslationSave(o, args);
 		}
 	}
@@ -426,15 +430,15 @@ public class EventHandlers {
 	/*	Help Menu */
 
 	public void OnHelpContents (object o, EventArgs args) {
-		Util.OpenUrl("ghelp:gnome-subtitles");
+		Util.OpenUrl("help:gnome-subtitles");
 	}
 
 	public void OnHelpKeyboardShortcuts (object o, EventArgs args) {
-		Util.OpenUrl("http://www.gnomesubtitles.org/shortcuts");
+		Util.OpenUrl("https://gnomesubtitles.org/shortcuts");
 	}
 	
 	public void OnHelpDonate (object o, EventArgs args) {
-		Util.OpenUrl("http://www.gnomesubtitles.org/donate");
+		Util.OpenUrl("https://gnomesubtitles.org/donate");
 	}
 
 	public void OnHelpRequestFeature (object o, EventArgs args) {
