@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2010 Pedro Castro
+ * Copyright (C) 2006-2017 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
  */
 
 using GnomeSubtitles.Core;
+using GnomeSubtitles.Ui;
 using GnomeSubtitles.Ui.Component;
 using GnomeSubtitles.Ui.VideoPreview;
-using Glade;
 using Gtk;
 using Mono.Unix;
 using SubLib.Core.Domain;
@@ -29,12 +29,12 @@ using System.Collections;
 using System.IO;
 using System.Text;
 using System.Text.RegularExpressions;
+using SubLib.Util;
 
 namespace GnomeSubtitles.Dialog {
 
-public class FileOpenDialog : GladeDialog {
-	protected FileChooserDialog dialog = null;
-
+public class FileOpenDialog : BaseDialog {
+	
 	private string chosenFilename = String.Empty;
 	private EncodingDescription chosenEncoding = EncodingDescription.Empty;
 	private ArrayList videoFiles = null; //The full paths of the video files in the current dir
@@ -42,52 +42,21 @@ public class FileOpenDialog : GladeDialog {
 	private Uri chosenVideoUri = null;
 	private bool autoChooseVideoFile = true;
 
-	/* Constant strings */
-	private const string gladeFilename = "FileOpenDialog.glade";
-
 	/* Components */
 	private EncodingComboBox encodingComboBox = null;
 
 	/* Widgets */
-	[WidgetAttribute] private ComboBox fileEncodingComboBox = null;
-	[WidgetAttribute] private ComboBox videoComboBox = null;
-	[WidgetAttribute] private Label videoLabel = null;
-	
-	
+	private ComboBoxText videoComboBox = null;
+	private Label videoLabel = null;
+
+
 	public FileOpenDialog () : this(true, Catalog.GetString("Open File")) {
 	}
-	
-	protected FileOpenDialog (bool toEnableVideo, string title) : base(gladeFilename) {
-		dialog = GetDialog() as FileChooserDialog;
-		dialog.Title = title;
 
-		InitEncodingComboBox();
-
-		if (toEnableVideo)
-			EnableVideo();
-	
-		string startFolder = GetStartFolder();
-		dialog.SetCurrentFolder(startFolder);
-
-		SetFilters();
+	protected FileOpenDialog (bool toEnableVideo, string title) : base() {
+		base.Init(BuildDialog(toEnableVideo, title));
 	}
 
-	private void InitEncodingComboBox () {
-		int fixedEncoding = -1;
-		ConfigFileOpenEncoding encodingConfig = Base.Config.PrefsDefaultsFileOpenEncoding;
-		if (encodingConfig == ConfigFileOpenEncoding.Fixed) {
-			string encodingName = Base.Config.PrefsDefaultsFileOpenEncodingFixed;
-			EncodingDescription encodingDescription = EncodingDescription.Empty;
-			Encodings.Find(encodingName, ref encodingDescription);
-			fixedEncoding = encodingDescription.CodePage;
-		}
-
-		this.encodingComboBox = new EncodingComboBox(fileEncodingComboBox, true, null, fixedEncoding);
-
-		/* Only need to handle the case of currentLocale, as Fixed is handled before and AutoDetect is the default behaviour */
-		if (encodingConfig == ConfigFileOpenEncoding.CurrentLocale)
-			encodingComboBox.ActiveSelection = (int)encodingConfig;
-	}
 
 	/* Overriden members */
 
@@ -95,6 +64,7 @@ public class FileOpenDialog : GladeDialog {
 		get { return DialogScope.Singleton; }
 	}
 
+
 	/* Public properties */
 
 	public EncodingDescription Encoding {
@@ -104,46 +74,106 @@ public class FileOpenDialog : GladeDialog {
 	public string Filename {
 		get { return chosenFilename; }
 	}
-	
+
 	public bool HasVideoFilename {
 		get { return chosenVideoUri != null; }
 	}
-	
+
 	public Uri VideoUri {
 		get { return chosenVideoUri; }
 	}
 
 
 	/* Protected members */
-	
+
 	protected virtual string GetStartFolder () {
-		if (Base.IsDocumentLoaded && Base.Document.TextFile.IsPathRooted)
+		if (Base.IsDocumentLoaded && Base.Document.TextFile.IsPathRooted) {
 			return Base.Document.TextFile.Directory;
-		else
+		} else {
 			return Environment.GetFolderPath(Environment.SpecialFolder.Personal);
+		}
 	}
 
 
 	/* Private members */
-	
+
+	private FileChooserDialog BuildDialog(bool toEnableVideo, string title) {
+		FileChooserDialog dialog = new FileChooserDialog(title, Base.Ui.Window, FileChooserAction.Open,
+			Util.GetStockLabel("gtk-cancel"), ResponseType.Cancel, Util.GetStockLabel("gtk-open"), ResponseType.Ok);
+
+		dialog.DefaultResponse = ResponseType.Ok;
+
+		//Build content area
+
+		Box box = new Box(Orientation.Horizontal, WidgetStyles.BoxSpacingMedium);
+		box.BorderWidth = WidgetStyles.BorderWidthMedium;
+
+		videoLabel = new Label(Catalog.GetString("Video To Open:"));
+		box.Add(videoLabel);
+		videoComboBox = new ComboBoxText();
+		videoComboBox.Hexpand = true;
+		CellRendererText videoComboBoxRenderer = (videoComboBox.Cells[0] as CellRendererText);
+		videoComboBoxRenderer.WidthChars = 20;
+		videoComboBoxRenderer.Ellipsize = Pango.EllipsizeMode.End;
+		box.Add(videoComboBox);
+
+		box.Add(new Label(Catalog.GetString("Character Encoding:")));
+
+		encodingComboBox = BuildEncodingComboBox();
+		box.Add(encodingComboBox.Widget);
+
+		dialog.ContentArea.Add(box);
+		dialog.ContentArea.ShowAll();
+
+		//Other stuff
+
+		SetFilters(dialog);
+		dialog.SetCurrentFolder(GetStartFolder());
+
+		if (toEnableVideo) {
+			EnableVideo(dialog);
+		}
+
+		return dialog;
+	}
+
+	private EncodingComboBox BuildEncodingComboBox () {
+		int fixedEncoding = -1;
+		ConfigFileOpenEncoding encodingConfig = Base.Config.FileOpenEncoding;
+		if (encodingConfig == ConfigFileOpenEncoding.Fixed) {
+			string encodingName = Base.Config.FileOpenEncodingFixed;
+			EncodingDescription encodingDescription = EncodingDescription.Empty;
+			Encodings.Find(encodingName, ref encodingDescription);
+			fixedEncoding = encodingDescription.CodePage;
+		}
+
+		EncodingComboBox comboBox = new EncodingComboBox(true, null, fixedEncoding);
+
+		/* Only need to handle the case of currentLocale, as Fixed is handled before and AutoDetect is the default behaviour */
+		if (encodingConfig == ConfigFileOpenEncoding.CurrentLocale) {
+			comboBox.ActiveSelection = (int)encodingConfig;
+		}
+
+		return comboBox;
+	}
+
 	private void FillVideoComboBoxBasedOnCurrentFolder () {
 		videoFiles = null;
 		videoFilenames = null;
-		(videoComboBox.Model as ListStore).Clear();
+		videoComboBox.RemoveAll();
 
 		string folder = String.Empty;
 		try {
-			folder = dialog.CurrentFolder;
+			folder = (Dialog as FileChooserDialog).CurrentFolder;
 		}
 		catch (Exception e) {
-			System.Console.Error.WriteLine("Caught exception when trying to get the current folder:");
-			System.Console.Error.WriteLine(e);
+			Logger.Error(e, "Caught exception when trying to get the current folder");
 			SetVideoSelectionSensitivity(false);
 			return;
 		}
-			
+
 		if ((folder == null) || (folder == String.Empty)) {
-			System.Console.Error.WriteLine("Error when trying to get the current folder.");
+			Logger.Error("Error when trying to get the current folder.");
 			SetVideoSelectionSensitivity(false);
 			return;
 		}
@@ -156,49 +186,48 @@ public class FileOpenDialog : GladeDialog {
 		}
 		else
 			SetVideoSelectionSensitivity(true);
-				
+
 		videoFiles.Sort();
 		videoFilenames = new ArrayList();
 		foreach (string file in videoFiles) {
 			string filename = Path.GetFileName(file);
 			videoComboBox.AppendText(filename);
-			
+
 			videoFilenames.Add(FilenameWithoutExtension(filename));
 		}
-		
+
 		videoComboBox.PrependText("-");
 		videoComboBox.PrependText(Catalog.GetString("None"));
 		videoComboBox.Active = 0;
 	}
-	
+
 	private void SetActiveVideoFile () {
 		if ((videoFiles == null) || (videoFiles.Count == 0))
 			return;
-		
+
 		string filePath = String.Empty;
 		try {
-			filePath = dialog.Filename;
+			filePath = (Dialog as FileChooserDialog).Filename;
 		}
 		catch (Exception e) {
-			System.Console.Error.WriteLine("Caught exception when trying to get the current filename:");
-			System.Console.Error.WriteLine(e);
+			Logger.Error(e, "Caught exception when trying to get the current filename");
 			SetActiveComboBoxItem(0);
 			return;
 		}
-		
+
 		if ((filePath == null) || (filePath == String.Empty) || (!File.Exists(filePath))) {
 			SetActiveComboBoxItem(0);
 			return;
 		}
-		
+
 		string filename = Path.GetFileNameWithoutExtension(filePath);
 		if ((filename == String.Empty) || (filename == null)) {
 			SetActiveComboBoxItem(0);
 			return;
 		}
-		
+
 		int activeVideoFile = 0;
-		
+
 		for (int count = 0 ; count < videoFilenames.Count ; count++) {
 			string videoFilename = videoFilenames[count] as string;
 			if (filename.Equals(videoFilename)) {
@@ -206,18 +235,18 @@ public class FileOpenDialog : GladeDialog {
 				break;
 			}
 		}
-		SetActiveComboBoxItem(activeVideoFile);		
+		SetActiveComboBoxItem(activeVideoFile);
 	}
-	
+
 	private void SetActiveComboBoxItem (int item) {
 		videoComboBox.Active = item;
 	}
-	
+
 	private void SetVideoSelectionSensitivity (bool sensitivity) {
 		videoComboBox.Sensitive = sensitivity;
 		videoLabel.Sensitive = sensitivity;
 	}
-	
+
 	private string FilenameWithoutExtension (string filename) {
 		int index = filename.LastIndexOf('.');
 		if (index != -1)
@@ -225,37 +254,40 @@ public class FileOpenDialog : GladeDialog {
 		else
 			return filename;
 	}
-	
-	private void EnableVideo () {
+
+	private void EnableVideo (FileChooserDialog dialog) {
 		videoLabel.Visible = true;
 		videoComboBox.Visible = true;
-		
-		autoChooseVideoFile = Base.Config.PrefsVideoAutoChooseFile;
+
+		autoChooseVideoFile = Base.Config.VideoAutoChooseFile;
 		videoComboBox.RowSeparatorFunc = ComboBoxUtil.SeparatorFunc;
-		
+
 		dialog.CurrentFolderChanged += OnCurrentFolderChanged;
 		dialog.SelectionChanged += OnSelectionChanged;
 	}
-	
-	private void SetFilters () {
+
+	/* Note: It would be nice show a separator after "All Subtitle Files" but filters
+	 * don't allow to set a separator function like we do in a normal combo box.
+	 */
+	private void SetFilters (FileChooserDialog dialog) {
 		SubtitleTypeInfo[] types = Subtitles.AvailableTypesSorted;
 		FileFilter[] filters = new FileFilter[types.Length + 2];
 		int filterPosition = 0;
-		
+
 		/* First filter corresponds to all files */
 		FileFilter allFilesFilter = new FileFilter();
 		allFilesFilter.Name = Catalog.GetString("All Files");
 		allFilesFilter.AddPattern("*");
 		filters[filterPosition] = allFilesFilter;
 		filterPosition++;
-		
+
 		/* Second filter corresponds to all subtitle files */
 		FileFilter subtitleFilesFilter = new FileFilter();
 		subtitleFilesFilter.Name = Catalog.GetString("All Subtitle Files");
 		subtitleFilesFilter.AddPattern("*.txt");
 		filters[filterPosition] = subtitleFilesFilter;
 		filterPosition++;
-		
+
 		/* Remaining filters correspond to the subtitle types */
 		foreach (SubtitleTypeInfo type in types) {
 			FileFilter filter = new FileFilter();
@@ -268,48 +300,47 @@ public class FileOpenDialog : GladeDialog {
 			filters[filterPosition] = filter;
 			filterPosition++;
 		}
-		
-		foreach (FileFilter filter in filters)
+
+		foreach (FileFilter filter in filters) {
 			dialog.AddFilter(filter);
-		
+		}
+
 		dialog.Filter = subtitleFilesFilter;
 	}
-	
-	
-	#pragma warning disable 169		//Disables warning about handlers not being used
+
 
 	protected override bool ProcessResponse (ResponseType response) {
 		if (response == ResponseType.Ok) {
-			chosenFilename = dialog.Filename;
+			chosenFilename = (Dialog as FileChooserDialog).Filename;
 			chosenEncoding = encodingComboBox.ChosenEncoding;
 
-			if (Base.Config.PrefsDefaultsFileOpenEncodingOption == ConfigFileOpenEncodingOption.RememberLastUsed) {
+			if (Base.Config.FileOpenEncodingOption == ConfigFileOpenEncodingOption.RememberLastUsed) {
 				int activeAction = encodingComboBox.ActiveSelection;
 				ConfigFileOpenEncoding activeOption = (ConfigFileOpenEncoding)Enum.ToObject(typeof(ConfigFileOpenEncoding), activeAction);
 				if (((int)activeOption) >= ((int)ConfigFileOpenEncoding.Fixed))
-					Base.Config.PrefsDefaultsFileOpenEncodingFixed = chosenEncoding.Name;
+					Base.Config.FileOpenEncodingFixed = chosenEncoding.Name;
 				else
-					Base.Config.PrefsDefaultsFileOpenEncoding = activeOption;
+					Base.Config.FileOpenEncoding = activeOption;
 			}
 
 			if (videoComboBox.Active > 0) {
 				int videoFileIndex = videoComboBox.Active - 2;
 				chosenVideoUri = new Uri("file://" + videoFiles[videoFileIndex] as string);
-			}			
+			}
 			SetReturnValue(true);
 		}
 		return false;
 	}
-	
+
 	private void OnCurrentFolderChanged (object o, EventArgs args) {
 		FillVideoComboBoxBasedOnCurrentFolder();
 	}
-	
+
 	private void OnSelectionChanged (object o, EventArgs args) {
 		if (autoChooseVideoFile)
 			SetActiveVideoFile();
 	}
-	
+
 }
 
 }
