@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2007-2009 Pedro Castro
+ * Copyright (C) 2007-2018 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@ using GStreamer;
 using Gtk;
 using SubLib.Core.Domain;
 using System;
+using SubLib.Util;
 
 namespace GnomeSubtitles.Ui.VideoPreview {
 
@@ -30,9 +31,9 @@ public delegate void PlayerErrorEventHandler (Uri videoUri, Exception e);
 public delegate void VideoDurationEventHandler (TimeSpan duration);
 
 public class Player {
-    
+
 	private AspectFrame frame = null;
-	private Socket socket = null;
+	//private Socket socket = null;
 	private Playbin playbin = null;
 	private PlayerPositionWatcher position = null;
 	private bool hasFoundDuration = false;
@@ -49,17 +50,17 @@ public class Player {
 	public Player (AspectFrame aspectFrame) {
 		this.frame = aspectFrame;
 
-		InitializeSocket();
+		//InitializeSocket();
 		InitializePositionWatcher();
 		InitializePlaybin();
 	}
 	
-	
+
 	/* Events */
 	public event PlayerErrorEventHandler Error;
 	public event EndOfStreamEventHandler EndOfStream;
 	public event StateEventHandler StateChanged;
-	public event PositionChangedEventHandler PositionChanged;
+	public event PositionPulseEventHandler PositionPulse;
 	public event VideoInfoEventHandler FoundVideoInfo;
 	public event VideoDurationEventHandler FoundDuration;
 
@@ -80,11 +81,11 @@ public class Player {
 	public bool HasVideoInfo {
 		get { return videoInfo != null; }
 	}
-	
+
 	public float AspectRatio {
 		get { return videoInfo.AspectRatio; }
 	}
-	
+
 	public float FrameRate {
 		get { return videoInfo.FrameRate; }
 	}
@@ -96,25 +97,25 @@ public class Player {
 	public bool HasVideo {
 		get { return videoInfo.HasVideo; }
 	}
-	
+
 	public Uri VideoUri {
 		get { return videoUri; }
 	}
-	
+
 	public float Speed {
 		get { return speed; }
 	}
 
 
 	/* Public methods */
-	
+
 	public void Open (Uri videoUri) {
 		this.videoUri = videoUri;
 
 		/* Load the playbin */
 		playbin.Load(videoUri.AbsoluteUri);
 	}
-	
+
 	public void Close () {
 		position.Stop();
 		playbin.Unload();
@@ -128,11 +129,11 @@ public class Player {
 	public void Play () {
 		playbin.Play();
 	}
-	
+
 	public void Pause () {
 		playbin.Pause();
 	}
-	
+
     public void SpeedUp () {
         if (this.speed >= DefaultMaxSpeed)
 	        return;
@@ -140,7 +141,7 @@ public class Player {
 		this.speed += DefaultSpeedStep;
 		ChangeSpeed(this.speed);
 	}
-	
+
 	public void SpeedDown () {
 	    if (this.speed <= DefaultMinSpeed)
 	        return;
@@ -148,28 +149,28 @@ public class Player {
 	    this.speed -= DefaultSpeedStep;
 		ChangeSpeed(this.speed);
 	}
-	
+
 	public void SpeedReset () {
 		this.speed = 1;
 		ChangeSpeed(this.speed);
 	}
-	
+
 	public void Rewind (TimeSpan dec) {
 		Seek(playbin.CurrentPosition - dec);
 	}
-	
+
 	public void Forward (TimeSpan inc) {
 		Seek(playbin.CurrentPosition + inc);
 	}
-	
+
 	public void Seek (TimeSpan newPosition) {
 		playbin.Seek(newPosition, speed);
 	}
-	
+
 	public void Seek (double newPosition) {
 		playbin.Seek(newPosition, speed); // newPosition in milliseconds
 	}
-	
+
 	public void Dispose () {
 		Close();
 		playbin.Dispose();
@@ -177,35 +178,57 @@ public class Player {
 
 
 	/* Private members */
-	
-	private void InitializeSocket () {
-		socket = new Socket();
-		socket.ModifyBg(StateType.Normal, socket.Style.Black);
 
-		frame.Child = socket;
 
-		socket.Realize();
-		socket.Show();
-	}
-	
+	//private void InitializeSocket () {
+	//	socket = new Socket();
+
+	//	/* Set the socket background color. If we don't do this, the socket/video
+	//	 * area will show a copy of the UI elements (menu, labels, other
+	//	 * components) when the video isn't loaded.
+	//	 */
+	//	RGBA black = new RGBA();
+	//	black.Red = 0;
+	//	black.Green = 0;
+	//	black.Blue = 0;
+	//	black.Alpha = 1;
+	//	socket.OverrideBackgroundColor(StateFlags.Normal, black);
+	//	socket.DoubleBuffered = false;
+
+	//	frame.Child = socket;
+
+	//	socket.Realize();
+	//	socket.Show();
+	//}
+
 	private void InitializePlaybin () {
 		playbin = new Playbin();
+
+		if (!playbin.Initiate()) {
+			throw new PlayerCouldNotInitiateEngineException("Unable to initiate the playbin engine");
+		}
 		
-		if (!playbin.Initiate(socket.Id))
-			throw new PlayerCouldNotInitiateEngineException();
-		
+		Widget videoWidget = playbin.GetVideoWidget();
+		if (videoWidget == null) {
+			throw new PlayerCouldNotInitiateEngineException("Unable to get the video widget from the playbin engine");
+		}
+
+		frame.Child = videoWidget;
+		videoWidget.Realize();
+		videoWidget.Show();
+
 		playbin.Error += OnPlaybinError;
 		playbin.EndOfStream += OnPlaybinEndOfStream;
 		playbin.StateChanged += OnPlaybinStateChanged;
 		playbin.FoundVideoInfo += OnPlaybinFoundVideoInfo;
 		playbin.FoundTag += OnPlaybinFoundTag;
 	}
-	
+
 	private void InitializePositionWatcher () {
 		position = new PlayerPositionWatcher(GetPosition);
-		position.Changed += OnPositionWatcherChanged;		
+		position.PositionPulse += OnPositionWatcherPulse;
 	}
-	
+
 	/// <summary>Gets the current player position.</summary>
 	private TimeSpan GetPosition () {
 		return playbin.CurrentPosition;
@@ -215,20 +238,20 @@ public class Player {
 	    playbin.Seek(playbin.CurrentPosition, newSpeed);
 	}
 
-		
+
 	/* Event members */
-	
+
 	private void OnPlaybinError (ErrorEventArgs args) {
 		if (Error != null)
 			Error(videoUri, new PlayerEngineException(args.Error, args.Debug));
 	}
-	
+
 	private void OnPlaybinEndOfStream () {
 		position.Stop();
 		if (EndOfStream != null)
 			EndOfStream();
 	}
-	
+
 	private void OnPlaybinStateChanged (StateEventArgs args) {
 		if (args.State == MediaStatus.Unloaded)
 			position.Stop();
@@ -238,14 +261,14 @@ public class Player {
 		if (StateChanged != null)
 			StateChanged(args);
 	}
-	
-	private void OnPositionWatcherChanged (TimeSpan time) {
-		if (PositionChanged != null)
-			PositionChanged(time);
+
+	private void OnPositionWatcherPulse (TimeSpan time) {
+		if (PositionPulse != null)
+			PositionPulse(time);
 	}
 
 	private void OnPlaybinFoundVideoInfo (VideoInfoEventArgs args) {
-		Console.Error.WriteLine("Got video info: " + args.VideoInfo.ToString());
+		Logger.Info("[Player] Media info: {0}", args.VideoInfo.ToString());
 		this.videoInfo = args.VideoInfo;
 
 		/* Set defaults if there is no video */
@@ -259,17 +282,17 @@ public class Player {
 		if (FoundVideoInfo != null)
 			FoundVideoInfo(args);
 	}
-	
+
 	private void OnPlaybinFoundTag (TagEventArgs args) {
 		if ((!hasFoundDuration) && (FoundDuration != null) && (playbin.Duration != TimeSpan.Zero)) {
 			TimeSpan duration = playbin.Duration;
-			Console.Error.WriteLine("Got video duration: " + duration);
-			
+			Logger.Info("[Player] Media duration: {0}", duration);
+
 			hasFoundDuration = true;
 			FoundDuration(duration);
 		}
 	}
-	
+
 }
 
 }
